@@ -5,7 +5,7 @@ use warnings;
 use warnings  qw(FATAL utf8); # Fatalize encoding glitches.
 
 our $Debug   = 0;
-our $VERSION = '1.23';
+our $VERSION = '1.24';
 
 use File::Slurp::Tiny 'read_lines';
 
@@ -973,23 +973,23 @@ sub new_daughter_left {
 
 sub node2string
 {
-	my($self, $options, $t, $vert_dashes) = @_;
-	my($depth)         = scalar($t -> ancestors) || 0;
-	my($sibling_count) = defined $t -> mother ? scalar $t -> self_and_sisters : 1;
-	my($offset)        = ' ' x 4;
+	my($self, $options, $node, $vert_dashes) = @_;
+	my($depth)         = scalar($node -> ancestors) || 0;
+	my($sibling_count) = defined $node -> mother ? scalar $node -> self_and_sisters : 1;
+	my($offset)        = ' ' x 5;
 	my(@indent)        = map{$$vert_dashes[$_] || $offset} 0 .. $depth - 1;
 	@$vert_dashes      =
 	(
 		@indent,
-		($sibling_count == 1 ? $offset : '   |'),
+		($sibling_count == 1 ? $offset : '    |'),
 	);
 
-	if ($sibling_count == ($t -> my_daughter_index + 1) )
+	if ($sibling_count == ($node -> my_daughter_index + 1) )
 	{
 		$$vert_dashes[$depth] = $offset;
 	}
 
-	return join('' => @indent[1 .. $#indent]) . ($depth ? '   |--- ' : '') . $self -> format_node($options, $t);
+	return join('' => @indent[1 .. $#indent]) . ($depth ? '    |--- ' : '') . $self -> format_node($options, $node);
 
 } # End of node2string.
 
@@ -1672,7 +1672,7 @@ Tree::DAG_Node - An N-ary tree
 
 =head1 SYNOPSIS
 
-Using as a base class:
+=head2 Using as a base class
 
 	package Game::Tree::Node;
 
@@ -1680,23 +1680,35 @@ Using as a base class:
 
 	# Now add your own methods overriding/extending the methods in C<Tree::DAG_Node>...
 
-Using as a class of its own:
+=head2 Using as a class of its own
 
 	use Tree::DAG_Node;
 
-	my $root = Tree::DAG_Node->new();
+	my($root) = Tree::DAG_Node -> new({name => 'root', attributes => {uid => 0} });
 
-	$root->name("I'm the tops");
-	my $new_daughter = $root->new_daughter;
-	$new_daughter->name("More");
+	$root -> add_daughter(Tree::DAG_Node -> new({name => 'one', attributes => {uid => 1} }) );
+	$root -> add_daughter(Tree::DAG_Node -> new({name => 'two', attributes => {} }) );
+	$root -> add_daughter(Tree::DAG_Node -> new({name => 'three'}) ); # Attrs default to {}.
+
+Or:
+
+	my $root = Tree::DAG_Node -> new();
+
+	$root -> name("I'm the tops");
+	$root -> attributes({uid => 0});
+
+	my $new_daughter = $root -> new_daughter;
+
+	$new_daughter -> name('Another node');
+	$new_daughter -> attributes({uid => 1});
 	...
 
-Using with utf-8 data:
+=head2 Using with utf-8 data
 
 	read_tree($file_name) works with utf-8 data. See t/read.tree.t and t/tree.utf8.attributes.txt.
 	Such a file can be created by redirecting the output of tree2string() to a file of type utf-8.
 
-See the docs for Encode for the difference between utf8 and utf-8. In brief, use utf-8.
+See the docs for L<Encode> for the difference between utf8 and utf-8. In brief, use utf-8.
 
 =head1 DESCRIPTION
 
@@ -1858,47 +1870,9 @@ daughters, 'attributes' setting of a new empty hashref), and returns
 the object created.  (If you just said "CLASS->new()" or "CLASS->new",
 then it pretends you called "CLASS->new({})".)
 
-Currently no options for putting in hashref $options are part
-of the documented interface, but the options is here in case
-you want to add such behavior in a derived class.
+See also the comments under L</new($hashref)> for options supported in the call to new().
 
-Read on if you plan on using Tree::DAG_New as a base class.
-(Otherwise feel free to skip to the description of _init.)
-
-There are, in my mind, two ways to do object construction:
-
-Way 1: create an object, knowing that it'll have certain uninteresting
-sane default values, and then call methods to change those values to
-what you want.  Example:
-
-    $node = Tree::DAG_Node->new;
-    $node->name('Supahnode!');
-    $root->add_daughter($node);
-    $node->add_daughters(@some_others)
-
-Way 2: be able to specify some/most/all the object's attributes in
-the call to the constructor.  Something like:
-
-    $node = Tree::DAG_Node->new({
-      name => 'Supahnode!',
-      mother => $root,
-      daughters => \@some_others
-    });
-
-After some deliberation, I've decided that the second way is a Bad
-Thing.  First off, it is B<not> markedly more concise than the first
-way.  Second off, it often requires subtly different syntax (e.g.,
-\@some_others vs @some_others).  It just complicates things for the
-programmer and the user, without making either appreciably happier.
-
-See however the comments under L</new($hashref)> for options newly supported in the call to new().
-
-(This is not to say that options in general for a constructor are bad
--- L</random_network($options)>, discussed far below, necessarily takes options.
-But note that those are not options for the default values of
-attributes.)
-
-Anyway, if you use C<Tree::DAG_Node> as a superclass, and you add
+If you use C<Tree::DAG_Node> as a superclass, and you add
 attributes that need to be initialized, what you need to do is provide
 an _init method that calls $this->SUPER::_init($options) to use its
 superclass's _init method, and then initializes the new attributes:
@@ -1912,48 +1886,6 @@ superclass's _init method, and then initializes the new attributes:
     $this->{'amigos'} = []; # for example
   }
 
-...or, as I prefer when I'm being a neat freak:
-
-  sub _init {
-    my($this, $options) = @_[0,1];
-    $this->SUPER::_init($options);
-
-    $this->_init_amigos($options);
-  }
-
-  sub _init_amigos {
-    my $this = $_[0];
-    # Or my($this,$options) = @_[0,1]; if I'm using $options
-    $this->{'amigos'} = [];
-  }
-
-
-In other words, I like to have each attribute initialized thru a
-method named _init_[attribute], which should expect the object as
-$_[0] and the options hashref (or {} if none was given) as $_[1].
-If you insist on having your _init recognize options for setting
-attributes, you might as well have them dealt with by the appropriate
-_init_[attribute] method, like this:
-
-  sub _init {
-    my($this, $options) = @_[0,1];
-    $this->SUPER::_init($options);
-
-    $this->_init_amigos($options);
-  }
-
-  sub _init_amigos {
-    my($this,$options) = @_[0,1]; # I need options this time
-    $this->{'amigos'} = [];
-    $this->amigos(@{$options->{'amigos'}}) if $options->{'amigos'};
-  }
-
-All this bookkeeping looks silly with just one new attribute in a
-class derived straight from C<Tree::DAG_Node>, but if there's lots of new
-attributes running around, and if you're deriving from a class derived
-from a class derived from C<Tree::DAG_Node>, then tidy
-stratification/modularization like this can keep you sane.
-
 =item the constructor $obj->new() or $obj->new($options)
 
 Just another way to get at the L</new($hashref)> method. This B<does not copy>
@@ -2165,7 +2097,7 @@ that'll be undef if $node is root.
 
 =head2 copy($option)
 
-Returns a copy the calling node (the invocant). E.g.: my($copy) = $node -> copy;
+Returns a copy of the calling node (the invocant). E.g.: my($copy) = $node -> copy;
 
 $option is a hashref of options, with these (key => value) pairs:
 
@@ -2357,7 +2289,7 @@ I<draw_ascii_tree()> tries to save vertical space.  Defaults to 1.
 The code occasionally returns trees that are a bit cock-eyed in parts; if
 anyone can suggest a better drawing algorithm, I'd be appreciative.
 
-See also L</tree2string([$options], [$some_tree])>.
+See also L</tree2string($options, [$some_tree])>.
 
 =head2 dump_names($options)
 
@@ -2370,8 +2302,8 @@ and continuing under it.  Options are:
 
 =item o _depth -- A nonnegative number
 
-Indicating the depth to consider $node as being at (and so the generation under that is that plus one,
-etc.).  You may choose to use set _depth => scalar($node->ancestors).
+Indicating the depth to consider $node as being at (and so the generation under that is that plus
+one, etc.).  You may choose to use set _depth => scalar($node->ancestors).
 
 Default: 0.
 
@@ -2395,9 +2327,7 @@ item is a line, with a "\n" at the end.
 
 Note: Names are converted to a printable form using the undocumented function _dump_quote().
 
-=head2 format_node([$options], [$node])
-
-Here, [] represent optional parameters.
+=head2 format_node($options, $node)
 
 Returns a string consisting of the node's name and, optionally, it's attributes.
 
@@ -2415,7 +2345,7 @@ Default: 0 (include attributes).
 
 Calls L</hashref2string($hashref)>.
 
-Called by L</node2string([$options], [$node])>.
+Called by L</node2string($options, $node, $vert_dashes)>.
 
 You would not normally call this method.
 
@@ -2457,11 +2387,11 @@ $node->generation_under($node) returns just $node.
 If you call $node->generation_under($node) but NODE2 is not $node or an
 ancestor of $node, it behaves as if you called just $node->generation().
 
-head2 hashref2string($hashref)
+=head2 hashref2string($hashref)
 
 Returns the given hashref as a string.
 
-Called by L</format_node([$options], [$node])>.
+Called by L</format_node($options, $node)>.
 
 =head2 is_daughter_of($node2)
 
@@ -2625,9 +2555,9 @@ daughter list, etc.
 
 As you'd expect for a constructor, it returns the node-object created.
 
-# Note that if you radically change 'mother'/'daughters' bookkeeping,
-# you may have to change this routine, since it's one of the places
-# that directly writes to 'daughters' and 'mother'.
+Note that if you radically change 'mother'/'daughters' bookkeeping,
+you may have to change this routine, since it's one of the places
+that directly writes to 'daughters' and 'mother'.
 
 =head2 new_daughter_left()
 
@@ -2636,11 +2566,11 @@ As you'd expect for a constructor, it returns the node-object created.
 This is just like $mother->new_daughter, but adds the new daughter
 to the left (start) of $mother's daughter list.
 
-# Note that if you radically change 'mother'/'daughters' bookkeeping,
-# you may have to change this routine, since it's one of the places
-# that directly writes to 'daughters' and 'mother'.
+Note that if you radically change 'mother'/'daughters' bookkeeping,
+you may have to change this routine, since it's one of the places
+that directly writes to 'daughters' and 'mother'.
 
-=head2 node2string($options, $t, $vert_dashes)
+=head2 node2string($options, $node, $vert_dashes)
 
 Returns a string of the node's name and attributes, with a leading indent, suitable for printing.
 
@@ -2656,9 +2586,11 @@ Default: 0 (include attributes).
 
 =back
 
-Calls L</format_node([$options], [$node])>.
+Ignore the parameter $vert_dashes. The code uses it as temporary storage.
 
-Called by L</tree2string([$options], [$some_tree])>.
+Calls L</format_node($options, $node)>.
+
+Called by L</tree2string($options, [$some_tree])>.
 
 =head2 random_network($options)
 
@@ -2681,7 +2613,8 @@ It takes four options:
 
 =over 4
 
-=item o max_node_count -- maximum number of nodes this tree will be allowed to have (counting the root)
+=item o max_node_count -- maximum number of nodes this tree will be allowed to have (counting the
+root)
 
 Default: 25.
 
@@ -2707,9 +2640,9 @@ Default: 4.
 =head2 read_attributes($s)
 
 Parses the string $s and extracts the name and attributes, assuming the format is as generated by
-L</tree2string([$options], [$some_tree])>.
+L</tree2string($options, [$some_tree])>.
 
-This bascially means the string was generated by L</hashref2string($hashref)>.
+This bascially means the attribute string was generated by L</hashref2string($hashref)>.
 
 Attributes may be absent, in which case they default to {}.
 
@@ -2723,14 +2656,15 @@ See t/tree.without.attributes.txt and t/tree.with.attributes.txt for sample data
 
 Returns the root of the tree read from $file_name.
 
-The file must have been written by re-directing the output of L</tree2string([$options], [$some_tree])> to a file,
-since it makes assumptions about the format of the stringified attributes.
+The file must have been written by re-directing the output of
+L</tree2string($options, [$some_tree])> to a file, since it makes assumptions about the format
+of the stringified attributes.
 
 read_tree() works with utf-8 data. See t/read.tree.t and t/tree.utf8.attributes.txt.
 
-Note: To call this method you need a caller. It'll be a tree of 1 node. The reason is that inside this method it
-calls various other methods, and for these calls it needs $self. That way, those methods can be called from
-anywhere, and not just from within read_tree().
+Note: To call this method you need a caller. It'll be a tree of 1 node. The reason is that inside
+this method it calls various other methods, and for these calls it needs $self. That way, those
+methods can be called from anywhere, and not just from within read_tree().
 
 For reading and writing trees to databases, see L<Tree::DAG_Node::Persist>.
 
@@ -2753,7 +2687,7 @@ and replacing it with the items in LIST.  This returns a list consisting
 of $node followed by LIST, i.e., the nodes that replaced it.
 
 LIST can include $node itself (presumably at most once).  LIST can
-also be empty-list.  However, if any items in LIST are sisters to
+also be the empty list.  However, if any items in LIST are sisters to
 $node, they are ignored, and are not in the copy of LIST passed as the
 return value.
 
@@ -2808,9 +2742,9 @@ $node->replace_with_daughters is a more common operation in
 tree-wrangling than $node->replace_with(LIST), so deserves a named
 method of its own, but that's just me.)
 
-# Note that if you radically change 'mother'/'daughters' bookkeeping,
-# you may have to change this routine, since it's one of the places
-# that directly writes to 'daughters' and 'mother'.
+Note that if you radically change 'mother'/'daughters' bookkeeping,
+you may have to change this routine, since it's one of the places
+that directly writes to 'daughters' and 'mother'.
 
 =head2 right_sister()
 
@@ -2897,7 +2831,8 @@ this returns empty-list.
 
 Returns a hashref built from the string.
 
-The string is expected to be something like '{AutoCommit => '1', PrintError => "0", ReportError => 1}'.
+The string is expected to be something like
+'{AutoCommit => '1', PrintError => "0", ReportError => 1}'.
 
 The empty string is returned as {}.
 
@@ -2960,9 +2895,9 @@ same options.
 
 Note: Names are converted to a printable form using the undocumented function _dump_quote().
 
-=head2 tree2string([$options], [$some_tree])
+=head2 tree2string($options, [$some_tree])
 
-Here, the [] represent optional parameters.
+Here, the [] represent an optional parameter.
 
 Returns an arrayref of lines, suitable for printing.
 
@@ -3046,7 +2981,7 @@ Default: 0 (include attributes).
 
 =back
 
-Calls L</node2string($options, $t, $vert_dashes)>.
+Calls L</node2string($options, $node, $vert_dashes)>.
 
 See also L</draw_ascii_tree([$options])>.
 
@@ -3110,7 +3045,7 @@ Note that if you don't specify I<_depth>, it effectively defaults to
 0.  You should set it to scalar($node->ancestors) if you want
 I<_depth> to reflect the true depth-in-the-tree for the nodes called,
 instead of just the depth below $node.  (If $node is the root, there's
-difference, of course.)
+no difference, of course.)
 
 And B<by the way>, it's a bad idea to modify the tree from the callback.
 Unpredictable things may happen.  I instead suggest having your callback
@@ -3363,16 +3298,20 @@ Programs>.)
 
 The file Changes was converted into Changelog.ini by L<Module::Metadata::Changes>.
 
+=head1 REPOSITORY
+
+L<https://github.com/ronsavage/Tree-DAG_Node>
+
 =head1 SUPPORT
 
 Email the author, or log a bug on RT:
 
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=Tree::DAG_Node>.
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Tree-DAG_Node>.
 
 =head1 ACKNOWLEDGEMENTS
 
-The code to print the tree, in tree2string(), was adapted from L<Forest::Tree::Writer::ASCIIWithBranches>
-by the dread Stevan Little.
+The code to print the tree, in tree2string(), was adapted from
+L<Forest::Tree::Writer::ASCIIWithBranches> by the dread Stevan Little.
 
 =head1 MAINTAINER
 
